@@ -282,7 +282,12 @@ pub fn run() -> Result<PathBuf, WorkflowError> {
             }
         }
         Err(e) => {
-            if path.is_file() && !matches!(e, WorkflowError::Template { .. }) && !ARGS.batch {
+            if path.is_file()
+                && !matches!(e, WorkflowError::Io { .. })
+                && !matches!(e, WorkflowError::File { .. })
+                && !matches!(e, WorkflowError::Template { .. })
+                && !ARGS.batch
+            {
                 missing_header = matches!(e, WorkflowError::MissingFrontMatter { .. })
                     || matches!(e, WorkflowError::MissingFrontMatterField { .. });
 
